@@ -6,9 +6,10 @@
 /* SYNOPSIS
 /*	#include <dns.h>
 /*
-/*	DNS_RR	*dns_rr_create(name, type, class, ttl, preference,
+/*	DNS_RR	*dns_rr_create(name, rname, type, class, ttl, preference,
 /*				data, data_len)
 /*	const char *name;
+/*	const char *rname;
 /*	unsigned short type;
 /*	unsigned short class;
 /*	unsigned int ttl;
@@ -30,6 +31,10 @@
 /*	DNS_RR	*list
 /*	int	(*compar)(DNS_RR *, DNS_RR *);
 /*
+/*	int	dns_rr_compare_pref(DNS_RR *a, DNS_RR *b)
+/*	DNS_RR	*list
+/*	DNS_RR	*list
+/*
 /*	DNS_RR	*dns_rr_shuffle(list)
 /*	DNS_RR	*list;
 /*
@@ -41,7 +46,8 @@
 /*	information, and maintain lists of DNS resource records.
 /*
 /*	dns_rr_create() creates and initializes one resource record.
-/*	The \fIname\fR record specifies the record name.
+/*	The \fIname\fR field specifies the query name.
+/*	The \fIrname\fR field specifies the reply name.
 /*	\fIpreference\fR is used for MX records; \fIdata\fR is a null
 /*	pointer or specifies optional resource-specific data;
 /*	\fIdata_len\fR is the amount of resource-specific data.
@@ -58,6 +64,9 @@
 /*	order according to a user-specified criterion. The result is the
 /*	sorted list.
 /*
+/*	dns_rr_compare_pref() is a dns_rr_sort() helper to sort records
+/*	by their MX preference.
+/*
 /*	dns_rr_shuffle() randomly permutes a list of resource records.
 /*
 /*	dns_rr_remove() removes the specified record from the specified list.
@@ -91,7 +100,8 @@
 
 /* dns_rr_create - fill in resource record structure */
 
-DNS_RR *dns_rr_create(const char *name, ushort type, ushort class,
+DNS_RR *dns_rr_create(const char *name, const char *rname,
+		              ushort type, ushort class,
 		              unsigned int ttl, unsigned pref,
 		              const char *data, size_t data_len)
 {
@@ -99,6 +109,7 @@ DNS_RR *dns_rr_create(const char *name, ushort type, ushort class,
 
     rr = (DNS_RR *) mymalloc(sizeof(*rr) + data_len - 1);
     rr->name = mystrdup(name);
+    rr->rname = mystrdup(rname);
     rr->type = type;
     rr->class = class;
     rr->ttl = ttl;
@@ -118,6 +129,7 @@ void    dns_rr_free(DNS_RR *rr)
 	if (rr->next)
 	    dns_rr_free(rr->next);
 	myfree(rr->name);
+	myfree(rr->rname);
 	myfree((char *) rr);
     }
 }
@@ -135,6 +147,7 @@ DNS_RR *dns_rr_copy(DNS_RR *src)
     dst = (DNS_RR *) mymalloc(len);
     memcpy((char *) dst, (char *) src, len);
     dst->name = mystrdup(src->name);
+    dst->rname = mystrdup(src->rname);
     dst->next = 0;
     return (dst);
 }
@@ -151,6 +164,23 @@ DNS_RR *dns_rr_append(DNS_RR *list, DNS_RR *rr)
     return (list);
 }
 
+/* dns_rr_compare_pref - compare resource records by preference */
+
+int     dns_rr_compare_pref(DNS_RR *a, DNS_RR *b)
+{
+    if (a->pref != b->pref)
+	return (a->pref - b->pref);
+#ifdef HAS_IPV6
+    if (a->type == b->type)			/* 200412 */
+	return 0;
+    if (a->type == T_AAAA)
+	return (-1);
+    if (b->type == T_AAAA)
+	return (+1);
+#endif
+    return 0;
+}
+
 /* dns_rr_sort_callback - glue function */
 
 static int (*dns_rr_sort_user) (DNS_RR *, DNS_RR *);
