@@ -201,7 +201,7 @@ static void abounce_event(int unused_event, char *context)
 
     event_disable_readwrite(vstream_fileno(ap->fp));
     abounce_done(ap, attr_scan(ap->fp, ATTR_FLAG_STRICT,
-			       ATTR_TYPE_INT, MAIL_ATTR_STATUS, &status,
+			       ATTR_TYPE_NUM, MAIL_ATTR_STATUS, &status,
 			       ATTR_TYPE_END) == 1 ? status : -1);
 }
 
@@ -233,14 +233,14 @@ static void abounce_request_verp(const char *class, const char *service,
     ap->fp = mail_connect_wait(class, service);
 
     if (attr_print(ap->fp, ATTR_FLAG_NONE,
-		   ATTR_TYPE_INT, MAIL_ATTR_NREQ, command,
-		   ATTR_TYPE_INT, MAIL_ATTR_FLAGS, flags,
+		   ATTR_TYPE_NUM, MAIL_ATTR_NREQ, command,
+		   ATTR_TYPE_NUM, MAIL_ATTR_FLAGS, flags,
 		   ATTR_TYPE_STR, MAIL_ATTR_QUEUE, queue,
 		   ATTR_TYPE_STR, MAIL_ATTR_QUEUEID, id,
 		   ATTR_TYPE_STR, MAIL_ATTR_ENCODING, encoding,
 		   ATTR_TYPE_STR, MAIL_ATTR_SENDER, sender,
 		   ATTR_TYPE_STR, MAIL_ATTR_DSN_ENVID, dsn_envid,
-		   ATTR_TYPE_INT, MAIL_ATTR_DSN_RET, dsn_ret,
+		   ATTR_TYPE_NUM, MAIL_ATTR_DSN_RET, dsn_ret,
 		   ATTR_TYPE_STR, MAIL_ATTR_VERPDL, verp,
 		   ATTR_TYPE_END) == 0
 	&& vstream_fflush(ap->fp) == 0) {
@@ -301,14 +301,14 @@ static void abounce_request(const char *class, const char *service,
     ap->fp = mail_connect_wait(class, service);
 
     if (attr_print(ap->fp, ATTR_FLAG_NONE,
-		   ATTR_TYPE_INT, MAIL_ATTR_NREQ, command,
-		   ATTR_TYPE_INT, MAIL_ATTR_FLAGS, flags,
+		   ATTR_TYPE_NUM, MAIL_ATTR_NREQ, command,
+		   ATTR_TYPE_NUM, MAIL_ATTR_FLAGS, flags,
 		   ATTR_TYPE_STR, MAIL_ATTR_QUEUE, queue,
 		   ATTR_TYPE_STR, MAIL_ATTR_QUEUEID, id,
 		   ATTR_TYPE_STR, MAIL_ATTR_ENCODING, encoding,
 		   ATTR_TYPE_STR, MAIL_ATTR_SENDER, sender,
 		   ATTR_TYPE_STR, MAIL_ATTR_DSN_ENVID, dsn_envid,
-		   ATTR_TYPE_INT, MAIL_ATTR_DSN_RET, dsn_ret,
+		   ATTR_TYPE_NUM, MAIL_ATTR_DSN_RET, dsn_ret,
 		   ATTR_TYPE_END) == 0
 	&& vstream_fflush(ap->fp) == 0) {
 	event_enable_read(vstream_fileno(ap->fp), abounce_event, (char *) ap);
