@@ -17,7 +17,7 @@
 /*		char	*nexthop;
 /*		char	*encoding;
 /*		char	*sender;
-/*		long arrival_time;
+/*		MSG_STATS msg_stats;
 /*		RECIPIENT_LIST rcpt_list;
 /*		DSN	*hop_status;
 /*		char	*client_name;
@@ -240,7 +240,7 @@ static int deliver_request_get(VSTREAM *stream, DELIVER_REQUEST *request)
 		  ATTR_TYPE_STR, MAIL_ATTR_SENDER, address,
 		  ATTR_TYPE_STR, MAIL_ATTR_DSN_ENVID, dsn_envid,
 		  ATTR_TYPE_NUM, MAIL_ATTR_DSN_RET, &dsn_ret,
-		  ATTR_TYPE_LONG, MAIL_ATTR_TIME, &request->arrival_time,
+	       ATTR_TYPE_FUNC, msg_stats_scan, (void *) &request->msg_stats,
 		  ATTR_TYPE_STR, MAIL_ATTR_CLIENT_NAME, client_name,
 		  ATTR_TYPE_STR, MAIL_ATTR_CLIENT_ADDR, client_addr,
 		  ATTR_TYPE_STR, MAIL_ATTR_PROTO_NAME, client_proto,
@@ -257,6 +257,10 @@ static int deliver_request_get(VSTREAM *stream, DELIVER_REQUEST *request)
 		     vstring_str(queue_id), &st, &path) == 0)
 	return (-1);
 
+    /* Don't override hand-off time after deliver_pass() delegation. */
+    if (request->msg_stats.agent_handoff.tv_sec == 0)
+	GETTIMEOFDAY(&request->msg_stats.agent_handoff);
+
     request->queue_name = mystrdup(vstring_str(queue_name));
     request->queue_id = mystrdup(vstring_str(queue_id));
     request->nexthop = mystrdup(vstring_str(nexthop));
@@ -300,6 +304,11 @@ static int deliver_request_get(VSTREAM *stream, DELIVER_REQUEST *request)
 			   vstring_str(orig_addr),
 			   vstring_str(address));
     }
+    if (request->rcpt_list.len <= 0) {
+	msg_warn("%s: no recipients in delivery request for destination %s",
+		 request->queue_id, request->nexthop);
+	return (-1);
+    }
 
     /*
      * Open the queue file and set a shared lock, in order to prevent
@@ -355,6 +364,7 @@ static DELIVER_REQUEST *deliver_request_alloc(void)
     request->sasl_username = 0;
     request->sasl_sender = 0;
     request->rewrite_context = 0;
+    request->dsn_envid = 0;
     return (request);
 }
 
