@@ -11,6 +11,12 @@
 /* DESCRIPTION
 /* .nf
 
+ /*
+  * System library.
+  */
+#include <ctype.h>
+#include <stdlib.h>
+
  /*
   * Diagnostic codes, not real record lookup results.
   */
@@ -43,6 +49,7 @@
 
 #define REC_TYPE_RDR	'>'		/* redirect target */
 #define REC_TYPE_FLGS	'f'		/* cleanup processing flags */
+#define REC_TYPE_DELAY	'd'		/* cleanup delay upon arrival */
 
 #define REC_TYPE_MESG	'M'		/* start message records */
 
