@@ -298,6 +298,9 @@
 /* .IP "\fBdaemon_timeout (18000s)\fR"
 /*	How much time a Postfix daemon process may take to handle a
 /*	request before it is terminated by a built-in watchdog timer.
+/* .IP "\fBdelay_logging_resolution_limit (2)\fR"
+/*	The maximal number of digits after the decimal point when logging
+/*	sub-second delay values.
 /* .IP "\fBexport_environment (see 'postconf -d' output)\fR"
 /*	The list of environment variables that a Postfix process will export
 /*	to non-Postfix processes.
@@ -893,7 +896,7 @@ static int eval_command_status(int command_status, char *service,
 	for (n = 0; n < request->rcpt_list.len; n++) {
 	    rcpt = request->rcpt_list.info + n;
 	    status = sent(DEL_REQ_TRACE_FLAGS(request->flags),
-			  request->queue_id, request->arrival_time, rcpt,
+			  request->queue_id, &request->msg_stats, rcpt,
 			  service, &dsn);
 	    if (status == 0 && (request->flags & DEL_REQ_FLAG_SUCCESS))
 		deliver_completed(src, rcpt->offset);
@@ -908,7 +911,7 @@ static int eval_command_status(int command_status, char *service,
 		rcpt = request->rcpt_list.info + n;
 		status = bounce_append(DEL_REQ_TRACE_FLAGS(request->flags),
 				       request->queue_id,
-				       request->arrival_time, rcpt,
+				       &request->msg_stats, rcpt,
 				       service, &dsn);
 		if (status == 0)
 		    deliver_completed(src, rcpt->offset);
@@ -919,7 +922,7 @@ static int eval_command_status(int command_status, char *service,
 		rcpt = request->rcpt_list.info + n;
 		result |= defer_append(DEL_REQ_TRACE_FLAGS(request->flags),
 				       request->queue_id,
-				       request->arrival_time, rcpt,
+				       &request->msg_stats, rcpt,
 				       service, &dsn);
 	    }
 	}
@@ -1029,7 +1032,7 @@ static int deliver_message(DELIVER_REQUEST *request, char *service, char **argv)
 	for (n = 0; n < request->rcpt_list.len; n++) {
 	    rcpt = request->rcpt_list.info + n;
 	    status = sent(DEL_REQ_TRACE_FLAGS(request->flags),
-			  request->queue_id, request->arrival_time,
+			  request->queue_id, &request->msg_stats,
 			  rcpt, service, DSN_FROM_DSN_BUF(&dsn, why));
 	    if (status == 0 && (request->flags & DEL_REQ_FLAG_SUCCESS))
 		deliver_completed(request->fp, rcpt->offset);
