@@ -29,8 +29,7 @@
 /*	smtpd_chat_reply() formats a server reply, sends it to the
 /*	client, and appends a copy to the SMTP transaction log.
 /*	When soft_bounce is enabled, all 5xx (reject) reponses are
-/*	replaced by 4xx (try again). In case of a 421 reply the
-/*	SMTPD_FLAG_HANGUP flag is set for orderly disconnect.
+/*	replaced by 4xx (try again).
 /*
 /*	smtpd_chat_notify() sends a copy of the SMTP transaction log
 /*	to the postmaster for review. The postmaster notice is sent only
@@ -137,7 +136,7 @@ void    smtpd_chat_query(SMTPD_STATE *state)
 
 /* smtpd_chat_reply - format, send and record an SMTP response */
 
-void    smtpd_chat_reply(SMTPD_STATE *state, const char *format,...)
+void    smtpd_chat_reply(SMTPD_STATE *state, char *format,...)
 {
     va_list ap;
     int     delay = 0;
@@ -180,12 +179,6 @@ void    smtpd_chat_reply(SMTPD_STATE *state, const char *format,...)
 	vstream_longjmp(state->client, SMTP_ERR_TIME);
     if (vstream_ferror(state->client))
 	vstream_longjmp(state->client, SMTP_ERR_EOF);
-
-    /*
-     * Orderly disconnect in case of 421 reply.
-     */
-    if (strncmp(STR(state->buffer), "421", 3) == 0)
-	state->flags |= SMTPD_FLAG_HANGUP;
 }
 
 /* print_line - line_wrap callback */
@@ -201,7 +194,7 @@ static void print_line(const char *str, int len, int indent, char *context)
 
 void    smtpd_chat_notify(SMTPD_STATE *state)
 {
-    const char *myname = "smtpd_chat_notify";
+    char   *myname = "smtpd_chat_notify";
     VSTREAM *notice;
     char  **cpp;
 
@@ -221,14 +214,13 @@ void    smtpd_chat_notify(SMTPD_STATE *state)
      * generate from untrusted data.
      */
 #define NULL_TRACE_FLAGS	0
-#define NO_QUEUE_ID		((VSTRING *) 0)
 #define LENGTH	78
 #define INDENT	4
 
     notice = post_mail_fopen_nowait(mail_addr_double_bounce(),
 				    var_error_rcpt,
-				    INT_FILT_NOTIFY,
-				    NULL_TRACE_FLAGS, NO_QUEUE_ID);
+				    CLEANUP_FLAG_MASK_INTERNAL,
+				    NULL_TRACE_FLAGS);
     if (notice == 0) {
 	msg_warn("postmaster notify: %m");
 	return;
