@@ -128,6 +128,10 @@
 #ifdef USE_TLS
 #include <string.h>
 
+#ifdef STRCASECMP_IN_STRINGS_H
+#include <strings.h>
+#endif
+
 /* Utility library. */
 
 #include <mymalloc.h>
@@ -693,6 +697,12 @@ TLScontext_t *tls_client_start(SSL_CTX *client_ctx, VSTREAM *stream,
     if (var_smtp_tls_loglevel < 4)
 	BIO_set_callback(SSL_get_rbio(TLScontext->con), 0);
 
+    /*
+     * The caller may want to know if this session was reused or if a new
+     * session was negotiated.
+     */
+    TLScontext->session_reused = SSL_session_reused(TLScontext->con);
+
     /*
      * Do peername verification if requested and extract useful information
      * from the certificate for later use.
