@@ -57,31 +57,18 @@
 /* TLS SESSION CACHE
 /* .ad
 /* .fi
-/* .IP "\fBlmtp_tls_loglevel (0)\fR"
-/*	The LMTP-specific version of the smtp_tls_loglevel
-/*	configuration parameter.
-/* .IP "\fBlmtp_tls_session_cache_database (empty)\fR"
-/*	The LMTP-specific version of the smtp_tls_session_cache_database
-/*	configuration parameter.
-/* .IP "\fBlmtp_tls_session_cache_timeout (3600s)\fR"
-/*	The LMTP-specific version of the smtp_tls_session_cache_timeout
-/*	configuration parameter.
-/* .IP "\fBsmtp_tls_loglevel (0)\fR"
-/*	Enable additional Postfix SMTP client logging of TLS activity.
-/* .IP "\fBsmtp_tls_session_cache_database (empty)\fR"
-/*	Name of the file containing the optional Postfix SMTP client
-/*	TLS session cache.
-/* .IP "\fBsmtp_tls_session_cache_timeout (3600s)\fR"
-/*	The expiration time of Postfix SMTP client TLS session cache
-/*	information.
-/* .IP "\fBsmtpd_tls_loglevel (0)\fR"
-/*	Enable additional Postfix SMTP server logging of TLS activity.
 /* .IP "\fBsmtpd_tls_session_cache_database (empty)\fR"
 /*	Name of the file containing the optional Postfix SMTP server
 /*	TLS session cache.
 /* .IP "\fBsmtpd_tls_session_cache_timeout (3600s)\fR"
 /*	The expiration time of Postfix SMTP server TLS session cache
 /*	information.
+/* .IP "\fBsmtp_tls_session_cache_database (empty)\fR"
+/*	Name of the file containing the optional Postfix SMTP client
+/*	TLS session cache.
+/* .IP "\fBsmtp_tls_session_cache_timeout (3600s)\fR"
+/*	The expiration time of Postfix SMTP client TLS session cache
+/*	information.
 /* PSEUDO RANDOM NUMBER GENERATOR
 /* .ad
 /* .fi
@@ -203,7 +190,6 @@
 /* TLS library. */
 
 #ifdef USE_TLS
-#include <tls.h>			/* TLS_MGR_SCACHE_<type> */
 #include <tls_prng.h>
 #include <tls_scache.h>
 
@@ -216,16 +202,6 @@ char   *var_tls_rand_source;
 int     var_tls_rand_bytes;
 int     var_tls_reseed_period;
 int     var_tls_prng_exch_period;
-int     var_smtpd_tls_loglevel;
-char   *var_smtpd_tls_scache_db;
-int     var_smtpd_tls_scache_timeout;
-int     var_smtp_tls_loglevel;
-char   *var_smtp_tls_scache_db;
-int     var_smtp_tls_scache_timeout;
-int     var_lmtp_tls_loglevel;
-char   *var_lmtp_tls_scache_db;
-int     var_lmtp_tls_scache_timeout;
-char   *var_tls_rand_exch_name;
 
  /*
   * Bound the time that we are willing to wait for an I/O operation. This
@@ -260,26 +236,17 @@ static TLS_PRNG_SRC *rand_source_file;
 #define EGD_PATH(egd) ((egd) + EGD_PREF_LEN)
 
  /*
-  * State for TLS session caches.
+  * State for TLS client and server session caches.
   */
-typedef struct {
-    char   *cache_label;
-    TLS_SCACHE *cache_info;
-    int     cache_active;
-    char  **cache_db;
-    int    *cache_loglevel;
-    int    *cache_timeout;
-} TLSMGR_SCACHE;
+static TLS_SCACHE *clnt_scache_info;	/* cache handle */
+static int clnt_scache_active;		/* scan in progress */
 
-TLSMGR_SCACHE cache_table[] = {
-    TLS_MGR_SCACHE_SMTPD, 0, 0, &var_smtpd_tls_scache_db,
-    &var_smtpd_tls_loglevel, &var_smtpd_tls_scache_timeout,
-    TLS_MGR_SCACHE_SMTP, 0, 0, &var_smtp_tls_scache_db,
-    &var_smtp_tls_loglevel, &var_smtp_tls_scache_timeout,
-    TLS_MGR_SCACHE_LMTP, 0, 0, &var_lmtp_tls_scache_db,
-    &var_lmtp_tls_loglevel, &var_lmtp_tls_scache_timeout,
-    0,
-};
+static TLS_SCACHE *srvr_scache_info;	/* cache handle */
+static int srvr_scache_active;		/* scan in progress */
+
+#define WHICH_CACHE_INFO(type) \
+    (type == TLS_MGR_SCACHE_CLIENT ? clnt_scache_info : \
+	type == TLS_MGR_SCACHE_SERVER ? srvr_scache_info : 0)
 
  /*
   * SLMs.
@@ -407,12 +374,11 @@ static void tlsmgr_reseed_event(int unused_event, char *dummy)
     event_request_timer(tlsmgr_reseed_event, dummy, next_period);
 }
 
-/* tlsmgr_cache_run_event - start TLS session cache scan */
+/* tlsmgr_clnt_cache_run_event - start SMTP client TLS session cache scan */
 
-static void tlsmgr_cache_run_event(int unused_event, char *ctx)
+static void tlsmgr_clnt_cache_run_event(int unused_event, char *dummy)
 {
-    const char *myname = "tlsmgr_cache_run_event";
-    TLSMGR_SCACHE *cache = (TLSMGR_SCACHE *) ctx;
+    const char *myname = "tlsmgr_clnt_cache_run_event";
 
     /*
      * This routine runs when it is time for another TLS session cache scan.
@@ -421,17 +387,41 @@ static void tlsmgr_cache_run_event(int unused_event, char *ctx)
      * Don't start a new scan when the timer goes off while cache cleanup is
      * still in progress.
      */
-    if (cache->cache_info->verbose)
-	msg_info("%s: start TLS %s session cache cleanup",
-		 myname, cache->cache_label);
+    if (var_smtp_tls_loglevel >= 3)
+	msg_info("%s: start TLS client session cache cleanup", myname);
 
-    if (cache->cache_active == 0)
-	cache->cache_active =
-	    tls_scache_sequence(cache->cache_info, DICT_SEQ_FUN_FIRST,
+    if (clnt_scache_active == 0)
+	clnt_scache_active =
+	    tls_scache_sequence(clnt_scache_info, DICT_SEQ_FUN_FIRST,
 				TLS_SCACHE_SEQUENCE_NOTHING);
 
-    event_request_timer(tlsmgr_cache_run_event, (char *) cache,
-			cache->cache_info->timeout);
+    event_request_timer(tlsmgr_clnt_cache_run_event, dummy,
+			var_smtp_tls_scache_timeout);
+}
+
+/* tlsmgr_srvr_cache_run_event - start SMTP server TLS session cache scan */
+
+static void tlsmgr_srvr_cache_run_event(int unused_event, char *dummy)
+{
+    const char *myname = "tlsmgr_srvr_cache_run_event";
+
+    /*
+     * This routine runs when it is time for another TLS session cache scan.
+     * Make sure this routine gets called again in the future.
+     * 
+     * Don't start a new scan when the timer goes off while cache cleanup is
+     * still in progress.
+     */
+    if (var_smtpd_tls_loglevel >= 3)
+	msg_info("%s: start TLS server session cache cleanup", myname);
+
+    if (srvr_scache_active == 0)
+	srvr_scache_active =
+	    tls_scache_sequence(srvr_scache_info, DICT_SEQ_FUN_FIRST,
+				TLS_SCACHE_SEQUENCE_NOTHING);
+
+    event_request_timer(tlsmgr_srvr_cache_run_event, dummy,
+			var_smtpd_tls_scache_timeout);
 }
 
 /* tlsmgr_loop - TLS manager main loop */
@@ -439,8 +429,6 @@ static void tlsmgr_cache_run_event(int unused_event, char *ctx)
 static int tlsmgr_loop(char *unused_name, char **unused_argv)
 {
     struct timeval tv;
-    int     active = 0;
-    TLSMGR_SCACHE *ent;
 
     /*
      * Update the PRNG pool with the time of day. We do it here after every
@@ -464,14 +452,18 @@ static int tlsmgr_loop(char *unused_name, char **unused_argv)
 #define DONT_WAIT	0
 #define WAIT_FOR_EVENT	(-1)
 
-    for (ent = cache_table; ent->cache_label; ++ent) {
-	if (ent->cache_info && ent->cache_active)
-	    active |= ent->cache_active =
-		tls_scache_sequence(ent->cache_info, DICT_SEQ_FUN_NEXT,
-				    TLS_SCACHE_SEQUENCE_NOTHING);
-    }
+    if (clnt_scache_active)
+	clnt_scache_active =
+	    tls_scache_sequence(clnt_scache_info, DICT_SEQ_FUN_NEXT,
+				TLS_SCACHE_SEQUENCE_NOTHING);
+    if (srvr_scache_active)
+	srvr_scache_active =
+	    tls_scache_sequence(srvr_scache_info, DICT_SEQ_FUN_NEXT,
+				TLS_SCACHE_SEQUENCE_NOTHING);
 
-    return (active ? DONT_WAIT : WAIT_FOR_EVENT);
+    if (clnt_scache_active || srvr_scache_active)
+	return (DONT_WAIT);
+    return (WAIT_FOR_EVENT);
 }
 
 /* tlsmgr_request_receive - receive request */
@@ -525,15 +517,15 @@ static void tlsmgr_service(VSTREAM *client_stream, char *unused_service,
 			           char **argv)
 {
     static VSTRING *request = 0;
-    static VSTRING *cache_type = 0;
     static VSTRING *cache_id = 0;
     static VSTRING *buffer = 0;
+    int     cache_type;
     int     len;
     static char wakeup[] = {		/* master wakeup request */
 	TRIGGER_REQ_WAKEUP,
 	0,
     };
-    TLSMGR_SCACHE *ent;
+    TLS_SCACHE *cache;
     int     status = TLS_MGR_STAT_FAIL;
 
     /*
@@ -547,7 +539,6 @@ static void tlsmgr_service(VSTREAM *client_stream, char *unused_service,
      */
     if (request == 0) {
 	request = vstring_alloc(10);
-	cache_type = vstring_alloc(10);
 	cache_id = vstring_alloc(10);
 	buffer = vstring_alloc(10);
     }
@@ -565,30 +556,20 @@ static void tlsmgr_service(VSTREAM *client_stream, char *unused_service,
 	 */
 	if (STREQ(STR(request), TLS_MGR_REQ_LOOKUP)) {
 	    if (attr_scan(client_stream, ATTR_FLAG_STRICT,
-			  ATTR_TYPE_STR, TLS_MGR_ATTR_CACHE_TYPE, cache_type,
+			ATTR_TYPE_NUM, TLS_MGR_ATTR_CACHE_TYPE, &cache_type,
 			  ATTR_TYPE_STR, TLS_MGR_ATTR_CACHE_ID, cache_id,
 			  ATTR_TYPE_END) == 2) {
-		for (ent = cache_table; ent->cache_label; ++ent)
-		    if (strcmp(ent->cache_label, STR(cache_type)) == 0)
-			break;
-		if (ent->cache_label == 0) {
-		    msg_warn("bogus cache type \"%s\" in \"%s\" request",
-			     STR(cache_type), TLS_MGR_REQ_LOOKUP);
-		    VSTRING_RESET(buffer);
-		} else if (ent->cache_info == 0) {
-
-		    /*
-		     * Cache type valid, but not enabled
-		     */
+		if ((cache = WHICH_CACHE_INFO(cache_type)) == 0) {
+		    msg_warn("bogus cache type \"%d\" in \"%s\" request",
+			     cache_type, TLS_MGR_REQ_LOOKUP);
 		    VSTRING_RESET(buffer);
 		} else {
-		    status = tls_scache_lookup(ent->cache_info,
-					       STR(cache_id), buffer) ?
+		    status = tls_scache_lookup(cache, STR(cache_id), buffer) ?
 			TLS_MGR_STAT_OK : TLS_MGR_STAT_ERR;
 		}
 	    }
 	    attr_print(client_stream, ATTR_FLAG_NONE,
-		       ATTR_TYPE_INT, MAIL_ATTR_STATUS, status,
+		       ATTR_TYPE_NUM, MAIL_ATTR_STATUS, status,
 		       ATTR_TYPE_DATA, TLS_MGR_ATTR_SESSION,
 		       LEN(buffer), STR(buffer),
 		       ATTR_TYPE_END);
@@ -599,25 +580,22 @@ static void tlsmgr_service(VSTREAM *client_stream, char *unused_service,
 	 */
 	else if (STREQ(STR(request), TLS_MGR_REQ_UPDATE)) {
 	    if (attr_scan(client_stream, ATTR_FLAG_STRICT,
-			  ATTR_TYPE_STR, TLS_MGR_ATTR_CACHE_TYPE, cache_type,
+			ATTR_TYPE_NUM, TLS_MGR_ATTR_CACHE_TYPE, &cache_type,
 			  ATTR_TYPE_STR, TLS_MGR_ATTR_CACHE_ID, cache_id,
 			  ATTR_TYPE_DATA, TLS_MGR_ATTR_SESSION, buffer,
 			  ATTR_TYPE_END) == 3) {
-		for (ent = cache_table; ent->cache_label; ++ent)
-		    if (strcmp(ent->cache_label, STR(cache_type)) == 0)
-			break;
-		if (ent->cache_label == 0) {
-		    msg_warn("bogus cache type \"%s\" in \"%s\" request",
-			     STR(cache_type), TLS_MGR_REQ_UPDATE);
-		} else if (ent->cache_info != 0) {
+		if ((cache = WHICH_CACHE_INFO(cache_type)) == 0) {
+		    msg_warn("bogus cache type \"%d\" in \"%s\" request",
+			     cache_type, TLS_MGR_REQ_UPDATE);
+		} else {
 		    status =
-			tls_scache_update(ent->cache_info, STR(cache_id),
+			tls_scache_update(cache, STR(cache_id),
 					  STR(buffer), LEN(buffer)) ?
 			TLS_MGR_STAT_OK : TLS_MGR_STAT_ERR;
 		}
 	    }
 	    attr_print(client_stream, ATTR_FLAG_NONE,
-		       ATTR_TYPE_INT, MAIL_ATTR_STATUS, status,
+		       ATTR_TYPE_NUM, MAIL_ATTR_STATUS, status,
 		       ATTR_TYPE_END);
 	}
 
@@ -626,23 +604,19 @@ static void tlsmgr_service(VSTREAM *client_stream, char *unused_service,
 	 */
 	else if (STREQ(STR(request), TLS_MGR_REQ_DELETE)) {
 	    if (attr_scan(client_stream, ATTR_FLAG_STRICT,
-			  ATTR_TYPE_STR, TLS_MGR_ATTR_CACHE_TYPE, cache_type,
+			ATTR_TYPE_NUM, TLS_MGR_ATTR_CACHE_TYPE, &cache_type,
 			  ATTR_TYPE_STR, TLS_MGR_ATTR_CACHE_ID, cache_id,
 			  ATTR_TYPE_END) == 2) {
-		for (ent = cache_table; ent->cache_label; ++ent)
-		    if (strcmp(ent->cache_label, STR(cache_type)) == 0)
-			break;
-		if (ent->cache_label == 0) {
-		    msg_warn("bogus cache type \"%s\" in \"%s\" request",
-			     STR(cache_type), TLS_MGR_REQ_DELETE);
-		} else if (ent->cache_info != 0) {
-		    status = tls_scache_delete(ent->cache_info,
-					       STR(cache_id)) ?
+		if ((cache = WHICH_CACHE_INFO(cache_type)) == 0) {
+		    msg_warn("bogus cache type \"%d\" in \"%s\" request",
+			     cache_type, TLS_MGR_REQ_DELETE);
+		} else {
+		    status = tls_scache_delete(cache, STR(cache_id)) ?
 			TLS_MGR_STAT_OK : TLS_MGR_STAT_ERR;
 		}
 	    }
 	    attr_print(client_stream, ATTR_FLAG_NONE,
-		       ATTR_TYPE_INT, MAIL_ATTR_STATUS, status,
+		       ATTR_TYPE_NUM, MAIL_ATTR_STATUS, status,
 		       ATTR_TYPE_END);
 	}
 
@@ -651,7 +625,7 @@ static void tlsmgr_service(VSTREAM *client_stream, char *unused_service,
 	 */
 	else if (STREQ(STR(request), TLS_MGR_REQ_SEED)) {
 	    if (attr_scan(client_stream, ATTR_FLAG_STRICT,
-			  ATTR_TYPE_INT, TLS_MGR_ATTR_SIZE, &len,
+			  ATTR_TYPE_NUM, TLS_MGR_ATTR_SIZE, &len,
 			  ATTR_TYPE_END) == 1) {
 		VSTRING_RESET(buffer);
 		if (len <= 0 || len > 255) {
@@ -666,7 +640,7 @@ static void tlsmgr_service(VSTREAM *client_stream, char *unused_service,
 		}
 	    }
 	    attr_print(client_stream, ATTR_FLAG_NONE,
-		       ATTR_TYPE_INT, MAIL_ATTR_STATUS, status,
+		       ATTR_TYPE_NUM, MAIL_ATTR_STATUS, status,
 		       ATTR_TYPE_DATA, TLS_MGR_ATTR_SEED,
 		       LEN(buffer), STR(buffer),
 		       ATTR_TYPE_END);
@@ -676,25 +650,19 @@ static void tlsmgr_service(VSTREAM *client_stream, char *unused_service,
 	 * Caching policy request.
 	 */
 	else if (STREQ(STR(request), TLS_MGR_REQ_POLICY)) {
-	    int     cachable = 0;
+	    int     cache_types = 0;
 
 	    if (attr_scan(client_stream, ATTR_FLAG_STRICT,
-			  ATTR_TYPE_STR, TLS_MGR_ATTR_CACHE_TYPE, cache_type,
-			  ATTR_TYPE_END) == 1) {
-		for (ent = cache_table; ent->cache_label; ++ent)
-		    if (strcmp(ent->cache_label, STR(cache_type)) == 0)
-			break;
-		if (ent->cache_label == 0) {
-		    msg_warn("bogus cache type \"%s\" in \"%s\" request",
-			     STR(cache_type), TLS_MGR_REQ_POLICY);
-		} else {
-		    cachable = (ent->cache_info != 0) ? 1 : 0;
-		    status = TLS_MGR_STAT_OK;
-		}
+			  ATTR_TYPE_END) == 0) {
+		if (clnt_scache_info)
+		    cache_types |= TLS_MGR_SCACHE_CLIENT;
+		if (srvr_scache_info)
+		    cache_types |= TLS_MGR_SCACHE_SERVER;
+		status = TLS_MGR_STAT_OK;
 	    }
 	    attr_print(client_stream, ATTR_FLAG_NONE,
-		       ATTR_TYPE_INT, MAIL_ATTR_STATUS, status,
-		       ATTR_TYPE_INT, TLS_MGR_ATTR_CACHABLE, cachable,
+		       ATTR_TYPE_NUM, MAIL_ATTR_STATUS, status,
+		       ATTR_TYPE_NUM, TLS_MGR_ATTR_POLICY, cache_types,
 		       ATTR_TYPE_END);
 	}
 
@@ -722,7 +690,7 @@ static void tlsmgr_service(VSTREAM *client_stream, char *unused_service,
      */
     else {
 	attr_print(client_stream, ATTR_FLAG_NONE,
-		   ATTR_TYPE_INT, MAIL_ATTR_STATUS, TLS_MGR_STAT_FAIL,
+		   ATTR_TYPE_NUM, MAIL_ATTR_STATUS, TLS_MGR_STAT_FAIL,
 		   ATTR_TYPE_END);
     }
     vstream_fflush(client_stream);
@@ -734,20 +702,16 @@ static void tlsmgr_pre_init(char *unused_name, char **unused_argv)
 {
     char   *path;
     struct timeval tv;
-    TLSMGR_SCACHE *ent;
 
     /*
      * If nothing else works then at least this will get us a few bits of
      * entropy.
-     * 
-     * XXX This is our first call into the OpenSSL library. We should find out
-     * if this can be moved to the post-jail initialization phase, without
-     * breaking compatibility with existing installations.
      */
     GETTIMEOFDAY(&tv);
     tv.tv_sec ^= getpid();
     RAND_seed(&tv, sizeof(struct timeval));
 
+
     /*
      * Open the external entropy source. We will not be able to open it again
      * after we are sent to chroot jail, so we keep it open. Errors are not
@@ -809,19 +773,22 @@ static void tlsmgr_pre_init(char *unused_name, char **unused_argv)
      * privileged. Start the cache maintenance pseudo threads after dropping
      * privileges.
      */
-    for (ent = cache_table; ent->cache_label; ++ent)
-	if (**ent->cache_db)
-	    ent->cache_info =
-		tls_scache_open(*ent->cache_db, ent->cache_label,
-			    *ent->cache_loglevel >= 2, *ent->cache_timeout);
+    if (*var_smtp_tls_scache_db)
+	clnt_scache_info =
+	    tls_scache_open(var_smtp_tls_scache_db, "client",
+			    var_smtp_tls_loglevel,
+			    var_smtp_tls_scache_timeout);
+    if (*var_smtpd_tls_scache_db)
+	srvr_scache_info =
+	    tls_scache_open(var_smtpd_tls_scache_db, "server",
+			    var_smtpd_tls_loglevel,
+			    var_smtpd_tls_scache_timeout);
 }
 
 /* tlsmgr_post_init - post-jail initialization */
 
 static void tlsmgr_post_init(char *unused_name, char **unused_argv)
 {
-    TLSMGR_SCACHE *ent;
-
 #define NULL_EVENT	(0)
 #define NULL_CONTEXT	((char *) 0)
 
@@ -858,9 +825,10 @@ static void tlsmgr_post_init(char *unused_name, char **unused_argv)
      * length, but early cleanup makes verbose logging more informative (we
      * get positive confirmation that the cleanup threads are running).
      */
-    for (ent = cache_table; ent->cache_label; ++ent)
-	if (ent->cache_info)
-	    tlsmgr_cache_run_event(NULL_EVENT, (char *) ent);
+    if (*var_smtp_tls_scache_db)
+	tlsmgr_clnt_cache_run_event(NULL_EVENT, NULL_CONTEXT);
+    if (*var_smtpd_tls_scache_db)
+	tlsmgr_srvr_cache_run_event(NULL_EVENT, NULL_CONTEXT);
 }
 
 /* tlsmgr_before_exit - save PRNG state before exit */
@@ -881,25 +849,15 @@ int     main(int argc, char **argv)
 {
     static CONFIG_STR_TABLE str_table[] = {
 	VAR_TLS_RAND_SOURCE, DEF_TLS_RAND_SOURCE, &var_tls_rand_source, 0, 0,
-	VAR_TLS_RAND_EXCH_NAME, DEF_TLS_RAND_EXCH_NAME, &var_tls_rand_exch_name, 0, 0,
-	VAR_SMTPD_TLS_SCACHE_DB, DEF_SMTPD_TLS_SCACHE_DB, &var_smtpd_tls_scache_db, 0, 0,
-	VAR_SMTP_TLS_SCACHE_DB, DEF_SMTP_TLS_SCACHE_DB, &var_smtp_tls_scache_db, 0, 0,
-	VAR_LMTP_TLS_SCACHE_DB, DEF_LMTP_TLS_SCACHE_DB, &var_lmtp_tls_scache_db, 0, 0,
 	0,
     };
     static CONFIG_TIME_TABLE time_table[] = {
 	VAR_TLS_RESEED_PERIOD, DEF_TLS_RESEED_PERIOD, &var_tls_reseed_period, 1, 0,
 	VAR_TLS_PRNG_UPD_PERIOD, DEF_TLS_PRNG_UPD_PERIOD, &var_tls_prng_exch_period, 1, 0,
-	VAR_SMTPD_TLS_SCACHTIME, DEF_SMTPD_TLS_SCACHTIME, &var_smtpd_tls_scache_timeout, 0, 0,
-	VAR_SMTP_TLS_SCACHTIME, DEF_SMTP_TLS_SCACHTIME, &var_smtp_tls_scache_timeout, 0, 0,
-	VAR_LMTP_TLS_SCACHTIME, DEF_LMTP_TLS_SCACHTIME, &var_lmtp_tls_scache_timeout, 0, 0,
 	0,
     };
     static CONFIG_INT_TABLE int_table[] = {
 	VAR_TLS_RAND_BYTES, DEF_TLS_RAND_BYTES, &var_tls_rand_bytes, 1, 0,
-	VAR_SMTPD_TLS_LOGLEVEL, DEF_SMTPD_TLS_LOGLEVEL, &var_smtpd_tls_loglevel, 0, 0,
-	VAR_SMTP_TLS_LOGLEVEL, DEF_SMTP_TLS_LOGLEVEL, &var_smtp_tls_loglevel, 0, 0,
-	VAR_LMTP_TLS_LOGLEVEL, DEF_LMTP_TLS_LOGLEVEL, &var_lmtp_tls_loglevel, 0, 0,
 	0,
     };
 
