@@ -20,18 +20,6 @@
 /*	In addition, vbuf_print() recognizes the %m format specifier
 /*	and expands it to the error message corresponding to the current
 /*	value of the global \fIerrno\fR variable.
-/* REENTRANCY
-/* .ad
-/* .fi
-/*	vbuf_print() allocates a static buffer. After completion
-/*	of the first vbuf_print() call, this buffer is safe for
-/*	reentrant vbuf_print() calls by (asynchronous) terminating
-/*	signal handlers or by (synchronous) terminating error
-/*	handlers. vbuf_print() initialization typically happens
-/*	upon the first formatted output to a VSTRING or VSTREAM.
-/*
-/*	However, it is up to the caller to ensure that the destination
-/*	VSTREAM or VSTRING buffer is protected against reentrant usage.
 /* LICENSE
 /* .ad
 /* .fi
@@ -108,9 +96,9 @@
 
 #define VBUF_STRCAT(bp, s) { \
 	unsigned char *_cp = (unsigned char *) (s); \
-	int _ch; \
-	while ((_ch = *_cp++) != 0) \
-	    VBUF_PUT((bp), _ch); \
+	int ch; \
+	while ((ch = *_cp++) != 0) \
+	    VBUF_PUT((bp), ch); \
     }
 
 /* vbuf_print - format string, vsprintf-like interface */
@@ -168,7 +156,7 @@ VBUF   *vbuf_print(VBUF *bp, const char *format, va_list ap)
 		VSTRING_ADDNUM(fmt, width);
 		cp++;
 	    } else {				/* hard-coded field width */
-		for (width = 0; ch = *cp, ISDIGIT(ch); cp++) {
+		for (width = 0; ISDIGIT(ch = *cp); cp++) {
 		    width = width * 10 + ch - '0';
 		    VSTRING_ADDCH(fmt, ch);
 		}
@@ -184,7 +172,7 @@ VBUF   *vbuf_print(VBUF *bp, const char *format, va_list ap)
 		VSTRING_ADDNUM(fmt, prec);
 		cp++;
 	    } else {				/* hard-coded precision */
-		for (prec = 0; ch = *cp, ISDIGIT(ch); cp++) {
+		for (prec = 0; ISDIGIT(ch = *cp); cp++) {
 		    prec = prec * 10 + ch - '0';
 		    VSTRING_ADDCH(fmt, ch);
 		}
