@@ -159,7 +159,7 @@ static int xsasl_cyrus_client_get_user(void *context, int unused_id,
 				               const char **result,
 				               unsigned *len)
 {
-    const char *myname = "xsasl_cyrus_get_user";
+    char   *myname = "xsasl_cyrus_get_user";
     XSASL_CYRUS_CLIENT *client = (XSASL_CYRUS_CLIENT *) context;
 
     if (msg_verbose)
@@ -182,7 +182,7 @@ static int xsasl_cyrus_client_get_user(void *context, int unused_id,
 static int xsasl_cyrus_client_get_passwd(sasl_conn_t *conn, void *context,
 				            int id, sasl_secret_t **psecret)
 {
-    const char *myname = "xsasl_cyrus_get_passwd";
+    char   *myname = "xsasl_cyrus_get_passwd";
     XSASL_CYRUS_CLIENT *client = (XSASL_CYRUS_CLIENT *) context;
     int     len;
 
@@ -300,7 +300,7 @@ XSASL_CLIENT *xsasl_cyrus_client_create(XSASL_CLIENT_IMPL *unused_impl,
     int     sasl_status;
 
     /*
-     * The optimizer will eliminate code duplication and/or dead code.
+     * The optimizer will eliminate duplication and/or dead code.
      */
 #define XSASL_CYRUS_CLIENT_CREATE_ERROR_RETURN(x) \
     do { \
@@ -379,7 +379,7 @@ static int xsasl_cyrus_client_set_security(XSASL_CLIENT *xp,
      * Per-session security properties. XXX This routine is not sufficiently
      * documented. What is the purpose of all this?
      */
-    memset(&sec_props, 0, sizeof(sec_props));
+    memset(&sec_props, 0L, sizeof(sec_props));
     sec_props.min_ssf = 0;
     sec_props.max_ssf = 0;			/* don't allow real SASL
 						 * security layer */
@@ -414,7 +414,7 @@ static int xsasl_cyrus_client_first(XSASL_CLIENT *xp,
 				            const char **mechanism,
 				            VSTRING *init_resp)
 {
-    const char *myname = "xsasl_cyrus_client_first";
+    char   *myname = "xsasl_cyrus_client_first";
     XSASL_CYRUS_CLIENT *client = (XSASL_CYRUS_CLIENT *) xp;
     unsigned enc_length;
     unsigned enc_length_out;
@@ -485,7 +485,7 @@ static int xsasl_cyrus_client_first(XSASL_CLIENT *xp,
 static int xsasl_cyrus_client_next(XSASL_CLIENT *xp, const char *server_reply,
 				           VSTRING *client_reply)
 {
-    const char *myname = "xsasl_cyrus_client_next";
+    char   *myname = "xsasl_cyrus_client_next";
     XSASL_CYRUS_CLIENT *client = (XSASL_CYRUS_CLIENT *) xp;
     unsigned enc_length;
     unsigned enc_length_out;
